package de.intevation.flys.importer;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.hibernate.Query;
import org.hibernate.Session;

import de.intevation.flys.model.River;
import de.intevation.flys.model.SedimentDensity;


public class ImportSedimentDensity {

    private static Logger log = Logger.getLogger(ImportSedimentDensity.class);

    protected SedimentDensity peer;

    protected ImportDepth depth;

    protected String description;

    protected List<ImportSedimentDensityValue> values;

    public ImportSedimentDensity(String description) {
        this.description = description;
        this.values = new ArrayList<ImportSedimentDensityValue>();
    }

    public String getDescription() {
        return description;
    }

    public void setDepth(ImportDepth depth) {
        this.depth = depth;
    }

    public void addValue(ImportSedimentDensityValue value) {
        values.add(value);
    }

    public void storeDependencies(River river) {
        log.info("store dependencies");

        if (depth != null) {
            depth.storeDependencies();
        }

        SedimentDensity peer = getPeer(river);

        if (peer != null) {
            log.info("store sediment density values.");
            for (ImportSedimentDensityValue value : values) {
                value.storeDependencies(peer);
            }
        }
    }

    public SedimentDensity getPeer(River river) {
        log.info("get peer");

        if (depth == null) {
            log.warn("cannot store sediment density '" + description
                + "': no depth");
            return null;
        }

        if (peer == null) {
            Session session = ImporterSession.getInstance()
                .getDatabaseSession();

            Query query = session.createQuery("from SedimentDensity where "
                + "   river=:river and " + "   depth=:depth");

            query.setParameter("river", river);
            query.setParameter("depth", depth.getPeer());

            List<SedimentDensity> density = query.list();

            if (density.isEmpty()) {
                log.debug("Create new SedimentDensity DB instance.");

                peer = new SedimentDensity(river, depth.getPeer(),
                    description);

                session.save(peer);
            }
            else {
                peer = density.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
